package de.hdm_stuttgart.mi.sda1;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.sql.*;

public class WriteRelationalData implements AutoCloseable {

  static final Logger log = LogManager.getLogger(WriteRelationalData.class);

  final Connection conn;
  final PreparedStatement insertLecturer,insertCourse;

  public WriteRelationalData(final Connection conn) throws SQLException {
    this.conn = conn;
    insertLecturer = conn.prepareStatement(
      "INSERT INTO Lecturer (ident, name, email) VALUES (?, ?, ?)",
      Statement.RETURN_GENERATED_KEYS);

    insertCourse = conn.prepareStatement(
      "INSERT INTO Course (number, lecturerer, title, description) VALUES (?, ?, ?, ?)",
      Statement.RETURN_GENERATED_KEYS);
  }

  @Override
  public void close() throws Exception {
    conn.close();
  }

  public long insertLecturer(final String ident, final String name, final String email) throws SQLException {

    insertLecturer.setString(1, ident);
    insertLecturer.setString(2, name);
    insertLecturer.setString(3, email);

    if (1 == insertLecturer.executeUpdate()) {
      try (final ResultSet generatedKeys = insertLecturer.getGeneratedKeys()) {
        if (generatedKeys.next()) {
          return generatedKeys.getLong(1);
        } else {
          log.warn("Unable to retrieve auto generated keys for record '" + name + "': ");
        }
      }
    }
    return -1;
  }
  public int insertCourse(final int number, final long lecturer, final String title, final String description)
    throws SQLException {
  log.info("lecturer: " + lecturer);
    insertCourse.setInt(1, number);
    insertCourse.setLong(2,   lecturer);
    insertCourse.setString(3, title);
    insertCourse.setString(4, description);

    return insertCourse.executeUpdate();
  }
}