package de.hdm_stuttgart.mi.sda1;

import org.junit.*;
import org.junit.rules.ExpectedException;
import org.junit.runners.MethodSorters;
import org.springframework.core.io.ClassPathResource;
import org.springframework.jdbc.datasource.init.ScriptUtils;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.SQLIntegrityConstraintViolationException;

/**
 * Testing SQL data insertion.
 */
@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class DatabaseTest {

  static Connection conn;

  static long goikId, hahnId;

  @BeforeClass
  static public void initDatabase() throws SQLException {
    conn = DriverManager.getConnection("jdbc:mysql://localhost:3306/hdm", "hdmuser", "XYZ");
    ScriptUtils.executeSqlScript(conn, new ClassPathResource("Data/universitySchema.sql"));
  }

  @AfterClass
  static public void releaseDatabase() throws SQLException {
    conn.close();
  }

  /**
   * first lecturer record.
   */
  @Test
  public void testDatabase_010 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);
    goikId = write.insertLecturer("goik", "Martin Goik", "goik@hdm-stuttgart.de");
    Assert.assertTrue( 0 < goikId);
  }
  /**
   * Testing duplicate insert.
   */
  @Test(expected = SQLIntegrityConstraintViolationException.class)
  public void testDatabase_020 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);
    Assert.assertEquals(1,
      write.insertLecturer("goik", "Martin Goik", "goik@hdm-stuttgart.de"));
  }
  /**
   * Second lecturer record having null email.
   */
  @Test
  public void testDatabase_030 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);

    hahnId = write.insertLecturer("hahn", "Jens Hahn", null);
    Assert.assertTrue(0 < hahnId);
  }
  /**
   * Insert lecture "Software Development 1"
   */
  @Test
  public void testDatabase_040 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);

    final int count = write.insertCourse(
      113105, goikId, "Software Development 1", "Introduction to Java");
    Assert.assertEquals(1, count);
  }
  /**
   * Try inserting duplicate lecture "Software Development 1"
   */
  @Test(expected = SQLIntegrityConstraintViolationException.class)
  public void testDatabase_050 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);

    final int count = write.insertCourse(
      113105, goikId, "Software Development 1", "Introduction to Java");
    Assert.assertEquals(1, count);
  }
  /**
   * Insert lecture "Mathematics"
   */
  @Test
  public void testDatabase_060 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);

    final int count = write.insertCourse(
      113109, hahnId, "Mathematics", null);
    Assert.assertEquals(1, count);
  }
  /**
   * Insert lecture "Structured data and applications"
   */
  @Test
  public void testDatabase_100 () throws SQLException {
    final WriteRelationalData write = new WriteRelationalData(conn);

    final int count = write.insertCourse(
      113305, goikId, "Structured data and applications", null);
    Assert.assertEquals(1, count);
  }
}
