package dom.xpath;

import java.io.IOException;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.Namespace;
import org.jdom2.filter.ElementFilter;
import org.jdom2.input.SAXBuilder;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

/** 
 * Checking external images accessibility 
 */
class CheckExtImage {
   private final SAXBuilder builder = new SAXBuilder();

   /** 
    * Read a HTML document and search for images. The image filenames will be
    * written to standard out.
    * @param htmlFilename The XHTML's filename to be examined.
    * @throws JDOMException General parsing fault
    * @throws IOException  file access problem
    */
   void process(final String htmlFilename) throws JDOMException, IOException {

      final Document htmlInput = builder.build(htmlFilename);  

      final Namespace htmlNamespace =                  // Allow for XPath expressions
            Namespace.getNamespace("h",          // handling HTML name
                  "http://www.w3.org/1999/xhtml"); // space prefix e.g. h:img

      final XPathExpression<Element> xpath = XPathFactory.instance().compile (
            "//h:img[starts-with(@src, 'http://') or " + // No XPath 2.0 regexp support yet, sigh!
                       "starts-with(@src, 'https://') or " +
                       "starts-with(@src, 'ftp://')]",
            new ElementFilter(), null, htmlNamespace);

      xpath.evaluate(htmlInput).stream().
         map(img -> img.getAttributeValue("src")).
         forEach(CheckExtImage::printResult);
   }
   
   static private void printResult(final String url) {
      System.out.println(url
            + ", HTTP Status: " + CheckUrl.checkReadability(url));
   }  
}